Module: DeviseRemote
- Defined in:
- lib/devise_remote/http_header_authenticatable_behavior.rb,
lib/devise_remote.rb,
lib/devise_remote/engine.rb,
lib/devise_remote/version.rb,
app/controllers/devise_remote/sessions_controller.rb,
app/controllers/devise_remote/application_controller.rb
Overview
Shared behavior for determining if a user is valid based on the headers passed into the Rails application from the authenticating service. At Penn State, this typically happens via WebAccess. Once the user is authenticated, the user’s network id (ex. abc123) is passed to the Passenger instance running the Rails application as an HTTP header. This module reads the headers to determine if there is a valid user present.
We can include this module in controllers to determine if user’s are valid. This is useful when making a public versus authenticated decision.
Defined Under Namespace
Modules: HttpHeaderAuthenticatableBehavior Classes: ApplicationController, Engine, InstallGenerator, LoginMigrationGenerator, SessionsController
Constant Summary collapse
- VERSION =
'0.1.0'
Class Attribute Summary collapse
-
.destroy_redirect_url ⇒ Object
Returns the value of attribute destroy_redirect_url.
-
.new_session_redirect_url ⇒ Object
Returns the value of attribute new_session_redirect_url.
-
.web_access_url ⇒ Object
Returns the value of attribute web_access_url.
Class Method Summary collapse
Class Attribute Details
.destroy_redirect_url ⇒ Object
Returns the value of attribute destroy_redirect_url.
11 12 13 |
# File 'lib/devise_remote.rb', line 11 def destroy_redirect_url @destroy_redirect_url end |
.new_session_redirect_url ⇒ Object
Returns the value of attribute new_session_redirect_url.
11 12 13 |
# File 'lib/devise_remote.rb', line 11 def new_session_redirect_url @new_session_redirect_url end |
.web_access_url ⇒ Object
Returns the value of attribute web_access_url.
11 12 13 |
# File 'lib/devise_remote.rb', line 11 def web_access_url @web_access_url end |
Class Method Details
.setup {|_self| ... } ⇒ Object
Mimics the same configuration process with Devise
15 16 17 |
# File 'lib/devise_remote.rb', line 15 def self.setup yield self end |